﻿using System;
using System.Collections.ObjectModel;
using System.Windows;

namespace SmileViewer
{
  internal class ViewModel : DependencyObject
  {
    public ViewModel()
    {
      Puts = new ObservableCollection<SpreadVM>();
      Calls = new ObservableCollection<SpreadVM>();
      Smile = new ObservableCollection<PriceVM>();

      DummyData();
    }

    private void DummyData()
    {
      const double spot = 25;
      var r = new Random();

      for (double strike = 0; strike < spot * 1.5; strike++)
      {
        var fair = (float) Math.Pow(strike - spot, 2)/500 + 5;
        var jitter = r.NextDouble() - 0.5;
        var spreadSize = strike == spot ? 0 : Math.Log(Math.Abs(strike - spot));

        var spread = new SpreadVM
                       {
                         Strike = strike,
                         Bid = fair + spreadSize/2 + jitter,
                         Ask = fair - spreadSize/2 + jitter,
                       };

        if (strike <= spot)
        {
          Calls.Add(SpreadVM.Empty);
          Puts.Add(spread);
        }
        else
        {
          Calls.Add(spread);
          Puts.Add(SpreadVM.Empty);
        }

        Smile.Add(new PriceVM {Fair = fair, Strike = strike});
      }
    }

    public ObservableCollection<SpreadVM> Puts { get; private set; }
    public ObservableCollection<SpreadVM> Calls { get; private set; }
    public ObservableCollection<PriceVM> Smile { get; private set; }
  }
}